@@ -1,4 +1,4 @@
-# Copyright (c) 2019 - 2022, Adrian Dusa
+# Copyright (c) 2019 - 2023, Adrian Dusa
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without
@@ -26,8 +26,5 @@
 `dashes` <- function() {
     irv <- c(45, 226, 128, 147)
     chrs <- rawToChar(as.raw(irv))
-    if (any(grepl("[^!-~ ]", chrs))) {
-        return("-")
-    }
-    paste(unlist(strsplit(chrs, split = "")), collapse = "|")
+    return(unlist(strsplit(chrs, split = "")))
 }
