@@ -1,4 +1,4 @@
-# Copyright (c) 2019 - 2022, Adrian Dusa
+# Copyright (c) 2019 - 2023, Adrian Dusa
 # All rights reserved.
 # 
 # Redistribution and use in source and binary forms, with or without
@@ -26,17 +26,34 @@
 `tildae` <- function() {
     irv <- c(126, 226, 136, 188, 194, 172, 226, 136, 189)
     chrs <- rawToChar(as.raw(irv))
-    if (any(grepl("[^!-~ ]", chrs))) {
-        return("~")
-    }
     unlist(strsplit(chrs, split = ""))
 }
+irv <- c(194, 160)
+multibyte_space <- rawToChar(as.raw(irv))
 `tilde1st` <- function(x) {
-    is.element(substring(gsub("[[:space:]]", "", x), 1, 1), tildae())
+    is.element(
+        substring(
+            gsub(
+                paste0("[[:space:]|", multibyte_space, "]"),
+                "",
+                x
+            ),
+            1, 1
+        ),
+        tildae()
+    )
 }
 `hastilde` <- function(x) {
     grepl(paste(tildae(), collapse = "|"), x)
 }
 `notilde` <- function(x) {
-    gsub(paste(tildae(), collapse = "|"), "", gsub("[[:space:]]", "", x))
+    gsub(
+        paste(tildae(), collapse = "|"),
+        "",
+        gsub(
+            paste0("[[:space:]|", multibyte_space, "]"),
+            "",
+            x
+        )
+    )
 }
